@@ -33,9 +33,10 @@
 #  define KXMLGUI_DEPRECATED_NO_EXPORT KXMLGUI_NO_EXPORT KXMLGUI_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KXMLGUI_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KXMLGUI_NO_DEPRECATED
+#    define KXMLGUI_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
